mongo_c_driver: MongoDB Client Library for C
============================================

Description
-----------

The MongoDB C Driver, also known as “libmongoc”, is a library for using MongoDB from C applications,
and for writing MongoDB drivers in higher-level languages.

In passagemath, it is used as a prerequisite of polymake's polyDB.


License
-------

Apache 2.0


Upstream Contact
----------------

https://mongoc.org/
